@@ -20,6 +20,7 @@ unset LOCAL             || true
 unset LOCALDEBS         || true
 unset SECURITY          || true
 unset PROPOSED_UPDATES  || true
+unset UNRELEASED        || true
 unset BOOTDIR           || true
 unset SYMLINK           || true
 unset COPYLINK          || true
@@ -62,7 +63,7 @@ export BASEDIR=`pwd`
 # export CDNAME=debian
 
 # Building $codename cd set ...
-export CODENAME=stretch
+export CODENAME=buster
 
 # By default use Debian installer packages from $CODENAME
 if [ -z "$DI_CODENAME" ]; then
@@ -166,6 +167,9 @@ export CONTRIB=1
 # NOTE: intended to be used for pre-release testing, not for publication!
 #export PROPOSED_UPDATES=$CODENAME-proposed-updates
 
+# Include packages from Debian Ports unreleased
+#export UNRELEASED=1
+
 # Sparc only : bootdir (location of cd.b and second.b)
 # export BOOTDIR=/boot
 
